[PATCH v2 1/2] string-list: use ALLOC_GROW macro when reallocing string_list
From: Jeff Hostetler <jeffhost@microsoft.com>
Use ALLOC_GROW() macro when reallocing a string_list array rather than simply increasing it by 32. This is a performance optimization.
During status on a very large repo and there are many changes, a significant percentage of the total run time was spent reallocing the wt_status.changes array.
This change decreased the time in wt_status_collect_changes_worktree() from 125 seconds to 45 seconds on my very large repository.
Signed-off-by: Jeff Hostetler <jeffhost@microsoft.com>
---
string-list.c | 5 +----
1 file changed, 1 insertion(+), 4 deletions(-)
Show changes to string-list.c +1 −4
diff --git a/string-list.c b/string-list.c
index 45016ad..003ca18 100644
--- a/string-list.c
+++ b/string-list.c
@@ -41,10 +41,7 @@ static int add_entry(int insert_at, struct string_list *list, const char *string
if (exact_match)
return -1 - index;
- if (list->nr + 1 >= list->alloc) {
- list->alloc += 32;
- REALLOC_ARRAY(list->items, list->alloc);
- }
+ ALLOC_GROW(list->items, list->nr+1, list->alloc);
if (index < list->nr)
memmove(list->items + index + 1, list->items + index,
(list->nr - index)
--
2.9.3